/*
 *                          Sun Public License Notice
 *
 * The contents of this file are subject to the Sun Public License Version
 * 1.0 (the "License"). You may not use this file except in compliance with
 * the License. A copy of the License is available at http://www.sun.com/
 *
 * The Original Code is the "Explore from here" NetBeans Module.
 * The Initial Developer of the Original Code is alessandro negrin.
 * Portions created by alessandro negrin are Copyright (C) 2005.
 * All Rights Reserved.
 *
 * Contributor(s): alessandro negrin.
 *
 */
package net.sf.efhnbm.options;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;
import java.util.ResourceBundle;
import javax.swing.BorderFactory;
import javax.swing.ButtonGroup;
import javax.swing.GroupLayout;
import javax.swing.JButton;
import javax.swing.JFileChooser;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JRadioButton;
import javax.swing.JTextField;
import javax.swing.LayoutStyle;
import org.openide.util.NbBundle;

/**
 * spi option panel
 *
 * @author alessandro negrin
 * @version $Id$
 */
public final class EFHOptionPanel extends JPanel {

    private final EFHPanelController controller;
    private static final long serialVersionUID = 9018890829648160858L;

    /**
     * Creates new form EFHOptionPanel.
     *
     * @param controller
     */
    public EFHOptionPanel(EFHPanelController controller) {
        initComponents();
        this.controller = controller;
    }

    void load() {
        EFHSettings settings = EFHSettings.getInstance();
        if (EFHSettings.PROP_OPTION_BUNDLE.equals(settings.getOption())) {
            getBundleOption().setSelected(true);
            getClassTextField().setEnabled(false);

            getCommandTextFieldExplore().setEnabled(false);
            getBrowseCommandButtonExplore().setEnabled(false);
            getCommandTextFieldSelect().setEnabled(false);
            getBrowseCommandButtonSelect().setEnabled(false);

        } else if (EFHSettings.PROP_OPTION_CLASS.equals(settings.getOption())) {
            getClassOption().setSelected(true);
            getClassTextField().setEnabled(true);

            getCommandTextFieldExplore().setEnabled(false);
            getBrowseCommandButtonExplore().setEnabled(false);
            getCommandTextFieldSelect().setEnabled(false);
            getBrowseCommandButtonSelect().setEnabled(false);

        } else if (EFHSettings.PROP_OPTION_COMMAND.equals(settings.getOption())) {
            getCommandOption().setSelected(true);
            getClassTextField().setEnabled(false);

            getCommandTextFieldExplore().setEnabled(true);
            getBrowseCommandButtonExplore().setEnabled(true);
            getCommandTextFieldSelect().setEnabled(true);
            getBrowseCommandButtonSelect().setEnabled(true);

        }
        getClassTextField().setText(settings.getLauncherClass());
        getCommandTextFieldExplore().setText(settings.getCommandExplore());
        getCommandTextFieldSelect().setText(settings.getCommandSelect());
    }

    void store() {
        EFHSettings settings = EFHSettings.getInstance();
        if (getBundleOption().isSelected()) {
            settings.setOption(EFHSettings.PROP_OPTION_BUNDLE);
        } else if (getClassOption().isSelected()) {
            settings.setOption(EFHSettings.PROP_OPTION_CLASS);
        } else if (getCommandOption().isSelected()) {
            settings.setOption(EFHSettings.PROP_OPTION_COMMAND);
        }
        settings.setLauncherClass(getClassTextField().getText());
        settings.setCommandExplore(getCommandTextFieldExplore().getText());
        settings.setCommandSelect(getCommandTextFieldSelect().getText());
        settings.firePropertiesHaveBeenChanged();
    }

    boolean valid() {
        // TODO check whether form is consistent and complete
        return true;
    }

    /**
     * This method is called from within the constructor to initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is always
     * regenerated by the Form Editor.
     */
    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
    private void initComponents() {

        optionGroup = new ButtonGroup();
        commandChooser = new JFileChooser();
        bundleOption = new JRadioButton();
        classOption = new JRadioButton();
        commandOption = new JRadioButton();
        classTextField = new JTextField();
        commandExploreLabel = new JLabel();
        commandSelectLabel = new JLabel();
        commandTextFieldExplore = new JTextField();
        browseCommandButtonSelect = new JButton();
        commandTextFieldSelect = new JTextField();
        browseCommandButtonExplore = new JButton();

        setBorder(BorderFactory.createTitledBorder(NbBundle.getMessage(EFHOptionPanel.class, "EFHOptionPanel.border.title"))); // NOI18N

        bundleOption.setBackground(null);
        optionGroup.add(bundleOption);
        ResourceBundle bundle = ResourceBundle.getBundle("net/sf/efhnbm/options/Bundle"); // NOI18N
        bundleOption.setText(bundle.getString("EFHOptionPanel.bundleOption.text")); // NOI18N
        bundleOption.setBorder(BorderFactory.createEmptyBorder(0, 0, 0, 0));
        bundleOption.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent evt) {
                onSelectBundle(evt);
            }
        });

        classOption.setBackground(null);
        optionGroup.add(classOption);
        classOption.setText(NbBundle.getMessage(EFHOptionPanel.class, "EFHOptionPanel.classOption.text")); // NOI18N
        classOption.setBorder(BorderFactory.createEmptyBorder(0, 0, 0, 0));
        classOption.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent evt) {
                onSelectClass(evt);
            }
        });

        commandOption.setBackground(null);
        optionGroup.add(commandOption);
        commandOption.setText(bundle.getString("EFHOptionPanel.commandOption.text")); // NOI18N
        commandOption.setBorder(BorderFactory.createEmptyBorder(0, 0, 0, 0));
        commandOption.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent evt) {
                onSelectCommand(evt);
            }
        });

        commandExploreLabel.setText(NbBundle.getMessage(EFHOptionPanel.class, "EFHOptionPanel.commandExploreLabel.text")); // NOI18N

        commandSelectLabel.setText(NbBundle.getMessage(EFHOptionPanel.class, "EFHOptionPanel.commandSelectLabel.text")); // NOI18N

        browseCommandButtonSelect.setText(bundle.getString("EFHOptionPanel.browseCommandButtonSelect.text")); // NOI18N
        browseCommandButtonSelect.addMouseListener(new MouseAdapter() {
            public void mouseReleased(MouseEvent evt) {
                onBrowseForCommandSelect(evt);
            }
        });

        browseCommandButtonExplore.setText(bundle.getString("EFHOptionPanel.browseCommandButtonExplore.text")); // NOI18N
        browseCommandButtonExplore.addMouseListener(new MouseAdapter() {
            public void mouseReleased(MouseEvent evt) {
                onBrowseForCommandExplore(evt);
            }
        });

        GroupLayout layout = new GroupLayout(this);
        this.setLayout(layout);
        layout.setHorizontalGroup(layout.createParallelGroup(GroupLayout.Alignment.LEADING)
            .addGroup(layout.createSequentialGroup()
                .addContainerGap()
                .addGroup(layout.createParallelGroup(GroupLayout.Alignment.LEADING)
                    .addGroup(layout.createSequentialGroup()
                        .addGap(12, 12, 12)
                        .addGroup(layout.createParallelGroup(GroupLayout.Alignment.LEADING)
                            .addComponent(commandSelectLabel)
                            .addComponent(commandExploreLabel)))
                    .addComponent(classOption))
                .addPreferredGap(LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(layout.createParallelGroup(GroupLayout.Alignment.LEADING)
                    .addComponent(classTextField)
                    .addComponent(commandTextFieldExplore, GroupLayout.DEFAULT_SIZE, 381, Short.MAX_VALUE)
                    .addComponent(commandTextFieldSelect))
                .addPreferredGap(LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(layout.createParallelGroup(GroupLayout.Alignment.LEADING)
                    .addComponent(browseCommandButtonExplore, GroupLayout.Alignment.TRAILING)
                    .addComponent(browseCommandButtonSelect, GroupLayout.Alignment.TRAILING)))
            .addGroup(layout.createSequentialGroup()
                .addGap(12, 12, 12)
                .addGroup(layout.createParallelGroup(GroupLayout.Alignment.LEADING)
                    .addComponent(commandOption)
                    .addComponent(bundleOption))
                .addContainerGap(GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
        );
        layout.setVerticalGroup(layout.createParallelGroup(GroupLayout.Alignment.LEADING)
            .addGroup(layout.createSequentialGroup()
                .addContainerGap()
                .addComponent(bundleOption)
                .addPreferredGap(LayoutStyle.ComponentPlacement.UNRELATED)
                .addGroup(layout.createParallelGroup(GroupLayout.Alignment.BASELINE)
                    .addComponent(classOption)
                    .addComponent(classTextField, GroupLayout.PREFERRED_SIZE, GroupLayout.DEFAULT_SIZE, GroupLayout.PREFERRED_SIZE))
                .addPreferredGap(LayoutStyle.ComponentPlacement.UNRELATED)
                .addComponent(commandOption)
                .addPreferredGap(LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(layout.createParallelGroup(GroupLayout.Alignment.BASELINE)
                    .addComponent(browseCommandButtonExplore)
                    .addComponent(commandTextFieldExplore, GroupLayout.PREFERRED_SIZE, GroupLayout.DEFAULT_SIZE, GroupLayout.PREFERRED_SIZE)
                    .addComponent(commandExploreLabel))
                .addPreferredGap(LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(layout.createParallelGroup(GroupLayout.Alignment.BASELINE)
                    .addComponent(browseCommandButtonSelect)
                    .addComponent(commandTextFieldSelect, GroupLayout.PREFERRED_SIZE, GroupLayout.DEFAULT_SIZE, GroupLayout.PREFERRED_SIZE)
                    .addComponent(commandSelectLabel))
                .addContainerGap(GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
        );
    }// </editor-fold>//GEN-END:initComponents

    private void onBrowseForCommandSelect(MouseEvent evt) {//GEN-FIRST:event_onBrowseForCommandSelect
        int result = commandChooser.showOpenDialog(this);
        if (result == JFileChooser.APPROVE_OPTION) {
            commandTextFieldSelect.setText(commandChooser.getSelectedFile().getAbsolutePath() + " {0}");
        }
    }//GEN-LAST:event_onBrowseForCommandSelect

    private void onBrowseForCommandExplore(MouseEvent evt) {//GEN-FIRST:event_onBrowseForCommandExplore
        int result = commandChooser.showOpenDialog(this);
        if (result == JFileChooser.APPROVE_OPTION) {
            commandTextFieldExplore.setText(commandChooser.getSelectedFile().getAbsolutePath() + " {0}");
        }
    }//GEN-LAST:event_onBrowseForCommandExplore

    private void onSelectCommand(ActionEvent evt) {//GEN-FIRST:event_onSelectCommand
        classTextField.setEnabled(false);
        commandTextFieldExplore.setEnabled(true);
        browseCommandButtonExplore.setEnabled(true);
        commandTextFieldSelect.setEnabled(true);
        browseCommandButtonSelect.setEnabled(true);
    }//GEN-LAST:event_onSelectCommand

    private void onSelectClass(ActionEvent evt) {//GEN-FIRST:event_onSelectClass
        classTextField.setEnabled(true);
        commandTextFieldExplore.setEnabled(false);
        browseCommandButtonExplore.setEnabled(false);
        commandTextFieldSelect.setEnabled(false);
        browseCommandButtonSelect.setEnabled(false);
    }//GEN-LAST:event_onSelectClass

    private void onSelectBundle(ActionEvent evt) {//GEN-FIRST:event_onSelectBundle
        classTextField.setEnabled(false);
        commandTextFieldExplore.setEnabled(false);
        browseCommandButtonExplore.setEnabled(false);
        commandTextFieldSelect.setEnabled(false);
        browseCommandButtonSelect.setEnabled(false);
    }//GEN-LAST:event_onSelectBundle

    // Variables declaration - do not modify//GEN-BEGIN:variables
    private JButton browseCommandButtonExplore;
    private JButton browseCommandButtonSelect;
    private JRadioButton bundleOption;
    private JRadioButton classOption;
    private JTextField classTextField;
    private JFileChooser commandChooser;
    private JLabel commandExploreLabel;
    private JRadioButton commandOption;
    private JLabel commandSelectLabel;
    private JTextField commandTextFieldExplore;
    private JTextField commandTextFieldSelect;
    private ButtonGroup optionGroup;
    // End of variables declaration//GEN-END:variables

    JRadioButton getBundleOption() {
        return bundleOption;
    }

    JRadioButton getClassOption() {
        return classOption;
    }

    JRadioButton getCommandOption() {
        return commandOption;
    }

    JTextField getClassTextField() {
        return classTextField;
    }

    JTextField getCommandTextFieldExplore() {
        return commandTextFieldExplore;
    }

    JButton getBrowseCommandButtonExplore() {
        return browseCommandButtonExplore;
    }

    JTextField getCommandTextFieldSelect() {
        return commandTextFieldSelect;
    }

    JButton getBrowseCommandButtonSelect() {
        return browseCommandButtonSelect;
    }

}
